@@ -394,12 +394,9 @@ def _determine_check_class_and_module(
 
 
 def _determine_check_class_name(name: str, section: configparser.SectionProxy) -> str:
-    # legacy method to determine the check name from the section header
-    class_name = name
     # if there is an explicit class, use that one with higher priority
-    if "class" in section:
-        class_name = section["class"]
-    return class_name
+    # else, use the legacy method to determine the check name from the section header
+    return section.get("class", name)
 
 
 def _set_up_single_check(
@@ -520,7 +517,9 @@ def parse_arguments(args: Optional[Sequence[str]]) -> argparse.Namespace:
 
     default_config: Optional[IO[str]] = None
     with suppress(FileNotFoundError, IsADirectoryError, PermissionError):
-        default_config = open("/etc/autosuspend.conf", "r")
+        # The open file is required after this function finishes inside the argparse
+        # result. Therefore, a context manager is not easily usable here.
+        default_config = open("/etc/autosuspend.conf", "r")  # noqa: SIM115
     parser.add_argument(
         "-c",
         "--config",
@@ -606,7 +605,7 @@ def configure_logging(config_file: Optional[IO], debug: bool) -> None:
     if config_file:
         try:
             logging.config.fileConfig(config_file)
-        except Exception:
+        except Exception:  # noqa: PIE786 probably ok for main-like function
             # at least configure warnings
             logging.basicConfig(level=logging.WARNING)
             _logger.warning(
