@@ -1393,19 +1393,20 @@ class TestLogindSessionsIdle(CheckTest):
         logind.AddSession("c1", "seat0", 1042, "auser", True)
 
         check = LogindSessionsIdle("test", ["test"], ["active", "online"])
-        check.check() is not None
+        assert check.check() is not None
 
+    @pytest.mark.skip(reason="No known way to set idle hint in dbus mock right now")
     def test_inactive(self, logind: ProxyObject) -> None:
         logind.AddSession("c1", "seat0", 1042, "auser", False)
 
         check = LogindSessionsIdle("test", ["test"], ["active", "online"])
-        check.check() is None
+        assert check.check() is None
 
     def test_ignore_unknow_type(self, logind: ProxyObject) -> None:
         logind.AddSession("c1", "seat0", 1042, "auser", True)
 
         check = LogindSessionsIdle("test", ["not_test"], ["active", "online"])
-        check.check() is None
+        assert check.check() is None
 
     def test_configure_defaults(self) -> None:
         parser = configparser.ConfigParser()
@@ -1576,7 +1577,7 @@ class TestLastLogActivity(CheckTest):
         return LastLogActivity(
             name=name,
             log_file=Path("some_file"),
-            pattern=re.compile(f"^(.*)$"),
+            pattern=re.compile("^(.*)$"),
             delta=timedelta(minutes=10),
             encoding="ascii",
             default_timezone=timezone.utc,
@@ -1725,16 +1726,15 @@ class TestLastLogActivity(CheckTest):
         # would match if timezone wasn't used
         file_path.write_text("2022-01-01", encoding="ascii")
 
-        with freeze_time("2020-02-02 12:15:00"):
-            with pytest.raises(TemporaryCheckError):
-                LastLogActivity(
-                    "test",
-                    file_path,
-                    re.compile(r"^(.*)$"),
-                    timedelta(minutes=10),
-                    "ascii",
-                    timezone.utc,
-                ).check()
+        with freeze_time("2020-02-02 12:15:00"), pytest.raises(TemporaryCheckError):
+            LastLogActivity(
+                "test",
+                file_path,
+                re.compile(r"^(.*)$"),
+                timedelta(minutes=10),
+                "ascii",
+                timezone.utc,
+            ).check()
 
     def test_fails_if_file_cannot_be_read(self, tmpdir: Path) -> None:
         file_path = tmpdir / "test.log"
